@@ -120,14 +120,22 @@ char *deviceList[] = {
    "/dev/usblp13",
    "/dev/usblp14",
    "/dev/usblp15",
+
    "/dev/ecpp0",       /* Solaris */
    "/dev/ecpp1",
    "/dev/ecpp2",
    "/dev/ecpp3",
    "/dev/ecpp4",
+
    "/dev/lpt0",        /* FreeBSD */
    "/dev/lpt1",
    "/dev/lpt2",
+   "/dev/ulpt0",
+   "/dev/ulpt1",
+   "/dev/ulpt2",
+   "/dev/unlpt0",
+   "/dev/unlpt1",
+   "/dev/unlpt2",
    NULL
 };
 
@@ -291,8 +299,7 @@ static int readDevDir(char **deviceName)
    DIR *dir;
    struct dirent *ent;
    char *fname = NULL;
-   
-   /* on mandrake 8.2 probleme with this !! */
+
    for (i = 0;  deviceList[i] != NULL; i++)
    {
       /* acess as group or user */
