@@ -591,9 +591,9 @@ static count=1;
          SetSensitive(True);
       }
       if ( retBuf )
-         decodeStatus(retBuf, strlen(retBuf));
+         decodeStatus((unsigned char*)retBuf, strlen(retBuf));
       else
-         decodeStatus("", 0);
+         decodeStatus((unsigned char*)"", 0);
       if ( retBuf && *retBuf ) doCyclicScan = 1;
       else doCyclicScan = 0;
       if ( oldCyclicScan && ! doCyclicScan &&
