@@ -52,13 +52,10 @@
 #include "mtink.h"
 #include "cmd.h"
 #include "d4lib.h"
-#include "d4libh.h"
 
 #ifdef MACOS
 #include "usbHlp.h"
 #include <pthread.h>
-#define write(a,b,c) mWrite(a,b,c)
-#define read(a,b,c) mRead(a,b,c)
 #define close mClose
 #define open mOpen
 
@@ -73,13 +70,6 @@
 #define TEST_DEBUG 0
 #endif
 
-#if 0 //TEST
-#define write(a,b,c) c
-#define writeData(a,b,c,d,e) d
-#define readData(a,b,c,d) d
-#define askForCredit(a,b,c,d) 1
-#endif
-
 #ifndef O_SYNC
 #define O_SYNC 0
 #endif
@@ -199,7 +189,7 @@ static unsigned char exchangeInkTerminate[] = {
 };
 
 
-static int _Write(int a, char *b, int c)
+static int _Write(int a, char *b, int c, int to)
 {
    int i;
    if ( debugD4 )
@@ -213,20 +203,20 @@ static int _Write(int a, char *b, int c)
          fprintf(stderr,"%c ",isprint(b[i])?b[i]:' ');
       fprintf(stderr,"\n");
    }
-   return write(a,b,c);
-}
-#ifdef MACOS
-#undef write
+#ifndef MACOS
+   return devWrite(a,b,c,to);
+#else   
+   return mWrite(a,b,c);
 #endif
-#define write(a,b,c) _Write(a,b,c)
+}
 
-static int _Read(int a,  char *b, int c)
+static int _Read(int a,  char *b, int c, int to)
 {
    int i;
-#ifdef MACOS
-   int ret = read(a,b,c);
-#else
-   int ret = devRead(a,b,c);
+#ifndef MACOS
+   int ret = devRead(a,b,c,to);
+# else
+   int ret = mRead(a,b,c);
 #endif
    if ( ret > 0 && debugD4 )
    {
@@ -241,10 +231,6 @@ static int _Read(int a,  char *b, int c)
    }
    return ret;
 }
-#ifdef MACOS
-#undef read
-#endif
-#define read(a,b,c) _Read(a,b,c)
 
 /******************************************************
  * Function: sigChild()
@@ -374,6 +360,9 @@ void *doCommands(void *dummy)
                     {
                         exitD4(deviceHdl);
                     }
+#if DEBUG
+                    fprintf(stderr,"Close(%d)\n",deviceHdl);
+#endif
                     close(deviceHdl);
                     deviceHdl = -1;
                  }
@@ -392,10 +381,13 @@ void *doCommands(void *dummy)
              break;
               case CHECK_NOZZLE:
                  shmem->retVal = checkNozzle(name,  mode&PALL);
+#if 1
                  if ( shmem->choice )
-		 {
+                 {
+		    sleep(10);
                     shmem->retVal = resetPrinter(name, mode&PALL );
                  }
+#endif
               break;
               case CLEAN_NOZZLE:
                  shmem->retVal = cleanNozzle(name,  mode&PALL);
@@ -425,6 +417,9 @@ void *doCommands(void *dummy)
 
           if ( errno == ENODEV && deviceHdl > -1 )
           {
+#if DEBUG
+              fprintf(stderr,"Close(%d)\n",deviceHdl);
+#endif
               close(deviceHdl);
               errno         = 0;
               deviceHdl     = -1;
@@ -438,6 +433,9 @@ void *doCommands(void *dummy)
                /* we had problems with the printer, restart from the begin */
              if ( d4Initialized )
                 exitD4(deviceHdl);
+#if DEBUG
+             fprintf(stderr,"Close(%d)\n",deviceHdl);
+#endif
              close(deviceHdl);
              deviceHdl     = -1;
              sockId        = -1;
@@ -648,7 +646,7 @@ int callPrg(int command, char *name, int mode, int pass, int choice, char **retB
    {
       return -1;
    }
- 
+
    /* check the shared memory */
    if ( shmctl(shmid, IPC_STAT, &buf) == -1 )
    {
@@ -778,7 +776,12 @@ int callPrg(int command, char *name, int mode, int pass, int choice, char **retB
       if ( errno == ENODEV )
       {
           if ( deviceHdl > 0 )
+          {
+#if DEBUG
+              fprintf(stderr,"Close(%d)\n",deviceHdl);
+#endif
              close(deviceHdl);
+          }
           deviceHdl = -1;
       }
       return -1;
@@ -980,8 +983,13 @@ int doCommand(int working)
          d4Initialized = 0;
          sockId        = -1;
          sockIdData    = -1;
-         if ( deviceHdl > -1 )            
+         if ( deviceHdl > -1 )
+         {
+#if DEBUG
+            fprintf(stderr,"Close(%d)\n",deviceHdl);
+#endif
             close(deviceHdl);
+         }
          deviceHdl = -1;
          shmem->retVal = 0;
          shmem->block  = 0;
@@ -1084,8 +1092,13 @@ int doCommand(int working)
          break;
          case CHECK_NOZZLE:
             shmem->retVal = checkNozzle(name,  mode&PALL);
+#if 1
             if ( shmem->choice )
+            {
+               sleep(10);
                shmem->retVal = resetPrinter(name, mode&PALL );
+            }
+#endif
             shmem->block = 0;
          break;
          case CLEAN_NOZZLE:
@@ -1168,10 +1181,12 @@ static void _sigAlarm(int code)
 #if DEBUG
    fprintf(stderr,"_sigAlarm got\n");
 #endif
+#ifdef linux
    doRw = 0;
-   ;
+#endif
 }
-
+#if 1
+#ifdef MACOS
 #define RESET_TIMER(ti,oti) { signal(SIGALRM, sig); \
                               memset((void*)&ti,0,sizeof(ti)); \
                               memset((void*)&oti,0,sizeof(oti)); \
@@ -1187,7 +1202,11 @@ static void _sigAlarm(int code)
                                 sig = signal(SIGALRM, _sigAlarm); \
                                 doRw = 1; \
                               }
-
+#else
+#define RESET_TIMER(ti,oti)
+#define SET_TIMER(ti,oti,val)
+#endif
+#endif
 
 /******************************************************
  * Function: openAndTestDevice()
@@ -1214,6 +1233,9 @@ static int openAndTestDevice(char *dev )
          /* exit from D4 */
          exitD4(deviceHdl);
       }
+#if DEBUG
+      fprintf(stderr,"Close(%d)\n",deviceHdl);
+#endif
       close(deviceHdl);
       deviceHdl     = -1;
    }
@@ -1223,8 +1245,12 @@ static int openAndTestDevice(char *dev )
 #if DEBUG
       fprintf(stderr,"Open %s\n",dev);
 #endif
-      SET_TIMER(ti,oti,5000);   
+      SET_TIMER(ti,oti,5000);
+#ifndef MACOS   
       if ( (deviceHdl = open(dev, O_RDWR|O_NDELAY)) == -1 )
+#else
+      if ( (deviceHdl = mOpen(dev, O_RDWR)) == -1 )
+#endif
       {
          /* Fatal error */
          RESET_TIMER(ti,oti);
@@ -1244,16 +1270,12 @@ static int openAndTestDevice(char *dev )
       d4RdTimeout = 200;
       for(i = 1; i > 0;)
       {
-         SET_TIMER(ti,oti,500);   
-         i = read(deviceHdl, iBuf, 511 );
-         RESET_TIMER(ti,oti);
+         i = _Read(deviceHdl, iBuf, 511, 500);
       }
       d4RdTimeout = oldTimeOut;
    }
 
-   SET_TIMER(ti,oti,500);   
-   len = write(deviceHdl, "\033\1@EJL ID\r\n",11);
-   RESET_TIMER(ti,oti);
+   len = _Write(deviceHdl, "\033\1@EJL ID\r\n",11, 500);
    if ( len != 11 )
    {
 #if DEBUG
@@ -1272,9 +1294,8 @@ static int openAndTestDevice(char *dev )
 #if DEBUG
       fprintf(stderr,"read from %s\n",dev);
 #endif
-      SET_TIMER(ti,oti,500);   
-      len = read(deviceHdl, shmem->buf, 511);
-      RESET_TIMER(ti,oti);
+
+      len = _Read(deviceHdl, shmem->buf, 511, 500);
       if ( len > 0 )
          break;
       usleep(50000);
@@ -1356,8 +1377,12 @@ static int openDevice(char *dev, int doTest )
 #if DEBUG
          fprintf(stderr,"Open %s\n",dev);
 #endif
-         SET_TIMER(ti,oti,5000);   
+         SET_TIMER(ti,oti,5000);
+#ifndef MACOS
          if ( (deviceHdl = open(dev, O_RDWR|O_NDELAY)) == -1 )
+#else
+         if ( (deviceHdl = mOpen(dev, O_RDWR)) == -1 )
+#endif
          {
             /* Fatal error */
             RESET_TIMER(ti,oti);
@@ -1379,9 +1404,7 @@ static int openDevice(char *dev, int doTest )
       d4RdTimeout = 200;
       for(i = 1; i > 0;)
       {
-         SET_TIMER(ti,oti,500);
-         i = read(deviceHdl, (char*)iBuf, 511 );
-         RESET_TIMER(ti,oti);
+         i = _Read(deviceHdl, (char*)iBuf, 511, 500);
       }
       d4RdTimeout = oldTimeOut;
    }
@@ -1416,11 +1439,7 @@ static int exitD4(int deviceHdl)
       CloseChannel(deviceHdl,sockId);
    sockIdData = sockId = -1;
 
-   SET_TIMER(ti,oti,500);
-   /*                       1 2 3   4 5678901234567 890123456 7*/
-   len = write(deviceHdl, "\0\0\0\033\1@EJL 1284.4\n@EJL     \n", 27);
-   RESET_TIMER(ti,oti);
-
+   len = _Write(deviceHdl, "\0\0\0\033\1@EJL 1284.4\n@EJL     \n", 27, 500);
    if ( len != 27 )
    {
       /* write failed */
@@ -1429,10 +1448,7 @@ static int exitD4(int deviceHdl)
    /* we have to wait a little bit */
    usleep(100000);
 
-   /* arm a timer so we will not block */
-   SET_TIMER(ti,oti,1000);   
-   len = read(deviceHdl, shmem->buf, 511);
-   RESET_TIMER(ti,oti);
+   len = _Read(deviceHdl, shmem->buf, 511, 1000);
    if ( len == -1 )
    {
       /* no information available */
@@ -1538,6 +1554,7 @@ return getIqD4(deviceHdl);
    /* block the printer if we query for identification with   */
    /* the old code, take account from them                    */
    int doTest = (prot & PROT_D4) ? 0 : 1;
+
    if ( deviceHdl == -1 )
    {
       if ( (deviceHdl = openDevice(name, doTest)) == -1 )
@@ -1557,7 +1574,6 @@ return getIqD4(deviceHdl);
          if ( ! d4Initialized )
             if ( initializeD4() )
                return 1;
-
          return getIqD4(deviceHdl);
       }
    }
@@ -1740,7 +1756,11 @@ int initializeD4()
    
    if ( sockId == 0 )
    {
+#if DEBUG
+      fprintf(stderr,"Close(%d)\n", deviceHdl);
+#endif
       close(deviceHdl);
+      deviceHdl = -1;
       return 1;
    }
 
@@ -1790,9 +1810,7 @@ static int getIdNoD4(int deviceHdl, int prot)
    if ( (prot & PROT_EXIT) )
       exitD4(deviceHdl);
 
-   SET_TIMER(ti,oti,500);
-   len = write(deviceHdl, "\033\1@EJL ID\r\n", 11);
-   RESET_TIMER(ti,oti);
+   len = _Write(deviceHdl, "\033\1@EJL ID\r\n", 11, 500);
    if ( len != 11 )
    {
 #if DEBUG
@@ -1806,9 +1824,7 @@ static int getIdNoD4(int deviceHdl, int prot)
    /* arm a timer so we will not block */
    for ( i = 0; i < 5; i++ )
    {
-      SET_TIMER(ti,oti,WRTIMEOUT);   
-      len = read(deviceHdl, shmem->buf, 511);
-      RESET_TIMER(ti,oti);
+      len = _Read(deviceHdl, shmem->buf, 511, WRTIMEOUT);
       if ( len > 0 )
          break;
       usleep(100000);
@@ -1842,11 +1858,8 @@ static int getIqOld(int deviceHdl, int prot)
    {
       exitD4(deviceHdl);
    }
- 
-   SET_TIMER(ti,oti,500);
-   /*                         12   34   567   8 9 0123456789 0 1 2   3 4 5 6 */
-   len = write(deviceHdl, "\033@\033@\033(R\010\0\0REMOTE1IQ\1\0\1\033\0\0\0", 26);
-   RESET_TIMER(ti,oti);
+
+   len = _Write(deviceHdl, "\033@\033@\033(R\010\0\0REMOTE1IQ\1\0\1\033\0\0\0", 26, 500);
    if ( len != 26 )
    {
       return 1;
@@ -1857,9 +1870,7 @@ static int getIqOld(int deviceHdl, int prot)
 
    for ( i = 0; i < 5; i++ )
    {
-      SET_TIMER(ti,oti,500);   
-      len = read(deviceHdl, shmem->buf, 511);
-      RESET_TIMER(ti,oti);
+      len = _Read(deviceHdl, shmem->buf, 511, 500);
       if ( len > 0 )
          break;
       usleep(1000000);
@@ -1896,9 +1907,7 @@ static int resetPrinterOld(int deviceHdl, int prot)
 
    if ( !(prot & PROT_D4) )
    {
-      SET_TIMER(ti,oti,500);
-      len = write(deviceHdl, (char*)resetCommand, resetCommandLen);
-      RESET_TIMER(ti,oti);
+      len = _Write(deviceHdl, (char*)resetCommand, resetCommandLen, 500);
       if ( len != 26 )
       {
          return 1;
@@ -1936,11 +1945,9 @@ static int checkNozzleOld(int deviceHdl, int prot)
    /* id was required before */
    if  ( (prot & PROT_EXIT )  )
       exitD4(deviceHdl);
- 
-   SET_TIMER(ti,oti,500);
-   len = write(deviceHdl,
-                "\033@\033@\033(R\010\0\0REMOTE1NC\2\0\0\0\033\0\0\0\f", 28);
-   RESET_TIMER(ti,oti);
+
+   len = _Write(deviceHdl,
+                "\033@\033@\033(R\010\0\0REMOTE1NC\2\0\0\0\033\0\0\0\f", 28, 500);
    if ( len != 28 )
    {
       return 1;
@@ -1967,9 +1974,7 @@ static int cleanNozzleOld(int deviceHdl, int prot)
    if  ( (prot & PROT_EXIT)  )
       exitD4(deviceHdl);
 
-   SET_TIMER(ti,oti,500);
-   len = write(deviceHdl, "\033@\033@\033(R\010\0\0REMOTE1CH\2\0\0\0\033\0\0\0", 27);
-   RESET_TIMER(ti,oti);
+   len = _Write(deviceHdl, "\033@\033@\033(R\010\0\0REMOTE1CH\2\0\0\0\033\0\0\0", 27, 500);
    if ( len != 27 )
    {
       return 1;
@@ -2444,8 +2449,10 @@ static int getIqD4(int deviceHdl)
    "5d 07 05 59 05 03 5d 10 06 01 0a 4e 08 4e 4e 13 01 01\0\0\0";
 */
    /* Stylus Photo R800 */
-   char hex[] = "40 42 44 43 20 53 54 32 0d 0a 5b 00 01 01 04 04 01 14 06 02 01 ff 0b 11 04 34 32 2f 37 30 30 32 34 36 35 "
-             "32 38 2b 30 2f 32 0f 19 03 05 03 25 04 02 52 03 01 1c 0b 00 2c 01 00 05 0c 09 54 0d 0a 0a 0e 0b 60 10 09 01 "
+   char hex[] = "40 42 44 43 20 53 54 32 0d 0a 5e 00 01 01 00 02 01 05 06 02 01 ff 0b 11 04 2f 31 32 34 31 30 32 36 2e 2d 34 35 34 31 31 36 0e 01 09 0f 19 03 05 03 00 04 02 55 03 01 3c 0b 00 60 01 00 5e 0c 09 10 0d 0a 0a 0e 0b 51 10 09 01 08 4e 0e 4e 4e 01 4e 4e 13 01 01 15 02 2e 00 19 0c 00 00 00 00 00 75 6e 6b 6e 6f 77 6e 1b 01 dd "
+
+/*"40 42 44 43 20 53 54 32 0d 0a 5b 00 01 01 04 04 01 14 06 02 01 ff 0b 11 04 34 32 2f 37 30 30 32 34 36 35 "
+             "32 38 2b 30 2f 32 0f 19 03 05 03 25 04 02 52 03 01 1c 0b 00 2c 01 00 05 0c 09 54 0d 0a 0a 0e 0b 60 10 09 01 "*/
            /*                         -- ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV */
            /*                          1  2  3  4  5  6  7  8  9  a  b  c  d  e  f 10 11 12 13 14 15 16 17 18 19 */
            /*                                Y 37     M 82     C 28     K 44     k  5     R 84     B 38     X 96 */
@@ -3003,9 +3010,7 @@ static int doAlignHead(char *name, int deviceHdl, int prot, int pass, int choice
       while (len > 0 )
       {
          toWrite = len > 1024 ? 1024 : len;
-         SET_TIMER(ti,oti,WRTIMEOUT);
-         i = write(deviceHdl, (char*)printer_cmd + pos, toWrite);
-         RESET_TIMER(ti,oti);
+         i = _Write(deviceHdl, (char*)printer_cmd + pos, toWrite,WRTIMEOUT);
          if ( i > 0 )
          {
             pos += i;
@@ -3103,9 +3108,7 @@ static int doAlignHeadColor(char *name, int deviceHdl, int prot, int pass, int c
       {
          exitD4(deviceHdl);
       }
-      SET_TIMER(ti,oti,WRTIMEOUT);   
-      i = write(deviceHdl, (char*)printer_cmd, bufpos);
-      RESET_TIMER(ti,oti);
+      i = _Write(deviceHdl, (char*)printer_cmd, bufpos, WRTIMEOUT);
       return i;
    }
 
