@@ -69,4 +69,6 @@ extern shmem_t *shmem;
 }
 #endif
 
+extern devRead(int fd, char *buf, int len, int timeout); 
+extern devWrite(int fd, char *buf, int len, int timeout); 
 #endif
