@@ -50,10 +50,7 @@
 #include "d4lib.h"
 
 #ifdef MACOS
-#define read(a,b,c)  mRead(a,b,c)
-#define write(a,b,c) mWrite(a,b,c)
-#else
-#define read(a,b,c)  devRead(a,b,c)
+#define USE_LIBUSB 1
 #endif
 
 #ifndef RDTIMEOUT
@@ -169,21 +166,6 @@ static errorMessage_t errorMessage[] =
    { 0x00, NULL                                                    ,0 }
 };
 
-#define RESET_TIMER(ti,oti) { signal(SIGALRM, sig); \
-                              memset((void*)&ti,0,sizeof(ti)); \
-                              memset((void*)&oti,0,sizeof(oti)); \
-                              setitimer( ITIMER_REAL ,&ti, &oti); \
-                              doRw = 0; \
-                            }
-
-#define SET_TIMER(ti,oti,val) { memset((void*)&ti,0,sizeof(ti)); \
-                                memset((void*)&oti,0,sizeof(oti)); \
-                                ti.it_value.tv_sec  = val/1000; \
-                                ti.it_value.tv_usec = (val%1000)*1000; \
-                                setitimer( ITIMER_REAL ,&ti, &oti); \
-                                sig = signal(SIGALRM, sigAlarm); \
-                                doRw = 1; \
-                              }
 
 /*******************************************************************/
 /* Function printHexValues                                         */
@@ -195,9 +177,6 @@ static errorMessage_t errorMessage[] =
 void printHexValues(char *dir, uc *buf, int len)
 {
    int i;
-#if 0
-   len = len > 30 ? 30 : len;
-#endif
    fprintf(stderr,"%s",dir);
    for ( i = 0; i < len;i++)
       fprintf(stderr,"%02x ",buf[i]);
@@ -334,9 +313,11 @@ static int writeCmd(int fd, unsigned char *cmd, int len)
    cnt = 0;
    while ( i < len )
    {
-      SET_TIMER(ti,oti,d4WrTimeout);         
-      w = write(fd, cmd+i,len-i);
-      RESET_TIMER(ti,oti);
+#ifndef USE_LIBUSB
+      w = devWrite(fd, cmd+i,len-i, d4WrTimeout );
+#else
+      w = mWrite(fd, cmd+i,len-i);
+#endif
       if ( w < 0 && errno == EAGAIN && cnt < 600 )
       {
          usleep(100000);
@@ -404,9 +385,11 @@ static int readAnswer(int fd, unsigned char *buf, int len)
 
    while ( total < len )
    {
-      SET_TIMER(ti,oti, d4RdTimeout);
-      rd = read(fd, buf+total, len-total);
-      RESET_TIMER(ti,oti);
+#ifndef USE_LIBUSB
+      rd = devRead(fd, buf+total, len-total, d4RdTimeout);
+#else
+      rd = mRead(fd, buf+total, len-total);
+#endif
       if ( rd <= 0 )
       {
          gettimeofday(&end, NULL);
@@ -415,7 +398,7 @@ static int readAnswer(int fd, unsigned char *buf, int len)
          if ( dt > d4RdTimeout || errno )
          {
             if ( debugD4 )
-               fprintf(stderr,"Timeout 1 at readAnswer() rcv %d bytes\n",total);
+               fprintf(stderr,"Timeout 1 at readAnswer() rcv %d bytes %d ms\n",total, dt);
             timeoutGot = 1;
             break;
          }
@@ -480,8 +463,6 @@ static int _readData(int fd, uc socketID, uc *buf, int len)
 {
    int rd    = 0;
    int total = 0;
-   int toGet = 0;
-   uc  header[6];
    struct timeval beg, end;
    long dt;
    struct itimerval ti, oti;
@@ -492,70 +473,32 @@ static int _readData(int fd, uc socketID, uc *buf, int len)
 
    /* read the first 6 bytes */
    gettimeofday(&beg, NULL);
-   while ( total < 6 )
+   while ( rd == 0 )
    {
-      SET_TIMER(ti,oti, d4RdTimeout);
-      rd = read(fd, header+total, 6-total);
-      RESET_TIMER(ti,oti);
-      if ( rd <= 0 )
+#ifndef USE_LIBUSB
+      rd = devRead(fd, buf, len, d4RdTimeout);
+#else
+      rd = mRead(fd, buf, len);
+#endif
+      gettimeofday(&end, NULL);
+      dt  = (end.tv_sec  - beg.tv_sec) * 1000;
+      dt += (end.tv_usec - beg.tv_usec) / 1000;
+      if ( dt > d4RdTimeout*3 )
       {
-         gettimeofday(&end, NULL);
-         dt  = (end.tv_sec  - beg.tv_sec) * 1000;
-         dt += (end.tv_usec - beg.tv_usec) / 1000;
-         if ( dt > d4RdTimeout*3 )
-         {
-            if ( debugD4 )
-               fprintf(stderr,"Timeout at _readData(), dt = %d ms\n",dt);
-
-            return -1;
-            break;
-         }
-         continue;
-      }
-      else
-      {
-         total += rd;
+         if ( debugD4 )
+            fprintf(stderr,"Timeout at _readData(), dt = %d ms\n",dt);
+         return -1;
       }
    }
 
    if ( debugD4 )
-      printHexValues("Recv: ",header,total);
+      printHexValues("Recv: ",buf,rd);
 
-   if ( total == 6 )
-   {
-      toGet = (header[2] >> 8) + header[3] - 6;
-      total = 0;
-      gettimeofday(&beg, NULL);
-      while ( total < toGet )
-      {
-         SET_TIMER(ti,oti, d4RdTimeout);
-         rd = read(fd, buf+total, toGet-total);
-         RESET_TIMER(ti,oti);
-         if ( rd <= 0 )
-         {
-            gettimeofday(&end, NULL);
-            dt  = (end.tv_sec  - beg.tv_sec) * 1000;
-            dt += (end.tv_usec - beg.tv_usec) / 1000;
-            if ( dt > d4RdTimeout*3 )
-            {
-               if ( debugD4 )
-                  fprintf(stderr,"Timeout at _readData(), dt = %d ms\n",dt);
-               return -1;
-               break;
-            }
-            continue;
-         }
-         else
-         {
-            total += rd;
-         }
-      }
-      if ( debugD4 )
-         printHexValues("Recv: ",buf,total);
-      return total;
-   }
+   total = rd -6;
+   if ( rd  > 0 )
+      memcpy(buf, buf+6, total);
 
-   return -1;
+   return total > 0 ? total : 0;
 }
 
 /*******************************************************************/
@@ -920,6 +863,7 @@ int Credit(int fd, uc socketID, int credit)
    buf[sizeof(cmdHeader_t)+2] = credit >> 8;
    buf[sizeof(cmdHeader_t)+3] = credit & 0xff;
    rd = sendReceiveCmd(fd, buf, 11, rBuf, 10);
+
    if ( rd == 10 )
    {
       return 1;
@@ -1031,9 +975,11 @@ int writeData(int fd, uc socketID, uc *buf, int len, int eoj)
    memcpy(buffer + 6, buf, len - 6 );
    while( ret > -1 && wr != len )
    {
-      SET_TIMER(ti,oti,d4WrTimeout);
-      ret = write(fd, buffer+wr, len-wr );
-      RESET_TIMER(ti,oti);
+#ifndef USE_LIBUSB
+      ret = devWrite(fd, buffer+wr, len-wr, d4WrTimeout);
+#else
+      ret = mWrite(fd, buffer+wr, len-wr );
+#endif
       if ( ret == -1 )
       {
          /* DEC-10-2005: resource temporary not available, on 2.6 
@@ -1130,11 +1076,13 @@ void clearSndBuf(int fd)
 {
    char             buf[256];
    struct itimerval ti, oti;
-   
-   SET_TIMER(ti,oti, d4RdTimeout);
-   while ( read(fd, buf, sizeof(buf) ) > 0 )
-      SET_TIMER(ti,oti, d4RdTimeout);
-   RESET_TIMER(ti,oti);
+#ifndef USE_LIBUSB
+   while ( devRead(fd, buf, sizeof(buf),  d4RdTimeout) > 0 )
+      ;
+#else
+   while ( mRead(fd, buf, sizeof(buf) ) > 0 )
+      ;
+#endif
 }
 
 
