@@ -68,6 +68,7 @@ static attr_t attr[] =
    { ".choicesNb:",           A_NB,     OFFSET(choices)          },
    { ".colorPassesNb:",       A_NB,     OFFSET(color_passes)     },
    { ".colorChoicesNb:",      A_NB,     OFFSET(color_choices)    },
+   { ".checkNozzleNeedReset:",A_FLAG,   OFFSET(checkNeedReset)   },
    { ".alignFunctionName:",   A_FNAME,  OFFSET(alignFunction)    },
    { ".END",                  D_END,    -1                       },  
    { NULL,                                                       }
@@ -258,7 +259,8 @@ static int readDataFile(FILE *fp)
                         }
                      break;
                      case A_NB:
-                        if ( *s >= '0' && *s <= '9' )
+                        if ( (*s == '-' && s[1] >= '0' && s[1] <= '9') ||
+                             (*s >= '0' && *s <= '9') )
                         {
                            is->i = atoi(s);
                         }
@@ -559,7 +561,10 @@ static void genCFile(configData_t *conf, int nb)
                printf("%2d, ", is->i);
             break;
             case A_FNAME:
-               printf("\"%s\" ", ss->s ? ss->s : "NULL");
+               if ( ss->s )
+                  printf("\"%s\" ", ss->s);
+               else
+                  printf("NULL ");
             break;
             case A_FLAG:
                if ( is->i ) printf("True,  ");
