@@ -41,10 +41,11 @@ static struct termios oldTerm;
 static struct termios newTerm;
 static int termInittialized = 0;
 
+#if 0
 /*******************************************************************/
 /* Function initTerm                                               */
 /*                                                                 */
-/* set terminal mode to raw and no echo so we can di simple editing*/
+/* set terminal mode to raw and no echo so we can do simple editing*/
 /*                                                                 */
 /*******************************************************************/
 
@@ -79,6 +80,10 @@ void resetTerm()
    if ( termInittialized )
       tcsetattr(fileno(stdin),TCSANOW,&oldTerm);
 }
+#else
+# define initTerm()
+# define resetTerm()
+#endif
 
 /*******************************************************************/
 /* Function mfgets()                                               */
@@ -623,3 +628,120 @@ int initResource()
    addFallback(0);
    return 0;
 }
+
+#if RESCHECK
+int searchCmp(char *key, char **res)
+{
+   char **cmp = res;
+   char  *s;
+   char  *e;
+   while (*res)
+   {
+      s = *res;
+      if ( *s == '.' || *s == '*' )
+      {
+         e = strchr(s, ':');
+         if ( e )
+         {
+            if ( s[3] == '.' )
+            {
+               if ( strncmp(key,s+4,e-s-4) == 0)
+               {
+                  return 1;
+               }
+            }
+            else
+            {
+               if ( strncmp(key,s+1,e-s-1) == 0)
+               {
+                  return;
+               }
+            }
+         }
+      }
+      res++;
+   }
+   return 0;
+}
+
+void checkForMissing(char **refRes, char **cmpRes)
+{
+   char **ref = refRes;
+   char   lang[20];
+   char   key[100];
+   char  *s;
+   char  *e;
+   while (*ref)
+   {
+      s = *ref;
+      if ( *s == '.' || *s == '*' )
+      {
+         e = strchr(s, ':');
+         if ( e )
+         {
+            if ( s[3] == '.' )
+            {
+               strncpy(key,s+4,e-s-3);
+               key[e-s-3] = '\0';
+            }
+            else
+            {
+               strncpy(key,s+1,e-s);
+               key[e-s] = '\0';
+            }
+            if ( searchCmp(key,cmpRes ) == 0 )
+            {
+               printf(" <.%s>\n",key);
+            }
+         }
+      }
+      ref++;
+   }
+}
+
+
+int main(int argc, char **argv)
+{
+   FILE  *refFp = NULL;
+   FILE  *cmpFp = NULL;
+   int    entriesRef;
+   int    entriesCmp;
+   char **resourcesRef;
+   if ( argc < 3 )
+   {
+      printf("Syntax: checkResource refFile cmpFile\n");
+      exit(1);
+   }
+   if ( (refFp = fopen(argv[1],"r")) != NULL )
+   {
+      if ( (cmpFp = fopen(argv[2],"r")) != NULL )
+      {
+         entriesRef = readResourceFile(refFp);
+         resourcesRef = resources;
+         resources = NULL;
+         entriesCmp = readResourceFile(cmpFp);
+         
+         printf("Missed resources\n");
+         checkForMissing(resourcesRef,resources);
+
+         printf("Resources not expected\n");
+         checkForMissing(resources,resourcesRef);
+         
+         fclose(refFp);
+         fclose(cmpFp);
+      }
+      else
+      {
+         fclose(refFp);
+         printf("can't open file %s\n",argv[2]);
+         exit(1);
+      }
+   }
+   else
+   {
+      printf("can't open file %s\n",argv[1]);
+      exit(1);
+   }
+   return 0;
+}
+#endif
