@@ -15,6 +15,7 @@
  *
  * Writing may be working for now without changes.
  */
+ 
 #ifndef MACOS
 #include <stdio.h>
 #include <unistd.h>
@@ -22,22 +23,18 @@
 #include <errno.h>
 #include <sys/time.h>
 #include <sys/poll.h>
+#include <signal.h>
 
-/* this variable is set before a read or write and reset
- * after the read is done or by the signal handler 
- */
-extern int doRw;
-
-int devRead(int fd, unsigned char *buf, size_t sz)
+ssize_t devRead(int fd, unsigned char *buf, size_t sz, int to)
 {
    int rd = 0;
-   int ms;
-
+   to /= 10;
    errno = 0;
-   while(doRw && rd != -1 )
+   while(to > 0 && rd != -1 )
    {
       /* wait a little bit */
       poll(NULL, 0, 10);
+      to--;
       rd = read(fd, buf, sz);
       if ( rd > 0 )
       {
@@ -51,4 +48,28 @@ int devRead(int fd, unsigned char *buf, size_t sz)
    }
    return -1;
 }
+
+ssize_t devWrite(int fd, unsigned char *buf, size_t sz, int to)
+{
+   int wr = 0;
+   to /= 10;
+   errno = 0;
+   while(to > 0 && wr != -1 )
+   {
+      /* wait a little bit */
+      poll(NULL, 0, 10);
+      to--;
+      wr = write(fd, buf, sz);
+      if ( wr > 0 )
+      {
+         return wr;
+      }
+   }
+   /* at this point we are probably interrupted */
+   if ( wr == 0 )
+   {
+      errno = EINTR;
+   }
+   return -1;
+}
 #endif
