@@ -628,9 +628,12 @@ char *fallbackResources[] = {
    "und whlen Sie die besten Linienpaare aus.\\n"
    "Legen Sie das Blatt erneut in den Drucker.",
 
-   ".choosePattern2:"
+   ".De.sampleNo:"
+   "Muster #",
+
+   ".De.choosePattern2:"
    "Bitte begutachten Sie das soeben gedruckte Muster,\\n"
-   "und whlen Sie die besten Linienpaare aus: Muster #",
+   "und whlen Sie die besten Linienpaare aus\\n",
 
 
    ".De.chooseCPattern:"
@@ -852,9 +855,12 @@ char *fallbackResources[] = {
    "und wählen Sie die besten Linienpaare aus.\\n"
    "Legen Sie das Blatt erneut in den Drucker.",
 
-   ".choosePattern2:"
+   ".De8.sampleNo:"
+   "Muster #",
+
+   ".De8.choosePattern2:"
    "Bitte begutachten Sie das soeben gedruckte Muster,\\n"
-   "und wählen Sie die besten Linienpaare aus: Muster #",
+   "und wählen Sie die besten Linienpaare aus\\n",
 
 
    ".De8.chooseCPattern:"
@@ -1085,9 +1091,12 @@ char *fallbackResources[] = {
    "from the last printed pattern.\\n"
    "Reinsert the sheet into the printer.",
 
+   "-sampleNo:"
+   "pattern #",
+
    ".choosePattern2:"
    "Please inspect the print, and choose the best pair of lines\\n"
-   "from the printed pattern #",
+   "from the printed pattern\\n",
 
    ".chooseCPattern:"
    "Inspect the alignment sheet, and determine which\\n"
@@ -1322,9 +1331,12 @@ char *fallbackResources[] = {
    "from the last printed pattern.\\n"
    "Reinsert the sheet into the printer.",
 
+   "-sampleNo:"
+   "pattern #",
+
    ".choosePattern2:"
    "Please inspect the print, and choose the best pair of lines\\n"
-   "from the printed pattern #",
+   "from the printed pattern\\n",
 
    ".chooseCPattern:"
    "Inspect the alignment sheet, and determine which\\n"
@@ -1563,9 +1575,12 @@ char *fallbackResources[] = {
    "de lignes.\\n"
    "Reinserez la feuille dans l'imprimante..",
 
+   ".Fr.sampleNo:"
+   "chantillon #",
+
    ".Fr.choosePattern2:"
    "Inpectez les lignes imprimes et choisissez la meilleure paire\\n"
-   "de lignes: chantillon #",
+   "de lignes\\n",
 
    ".Fr.chooseCPattern:"
    "Inspectez la feuille d'alignement et determinez l'chantillon\\n"
@@ -1803,9 +1818,12 @@ char *fallbackResources[] = {
    "de lignes.\\n"
    "Reinserez la feuille dans l'imprimante..",
 
+   ".Fr8.sampleNo:"
+   "échantillon #",
+
    ".Fr8.choosePattern2:"
    "Inpectez les lignes imprimées et choisissez la meilleure paire\\n"
-   "de lignes: échantillon #",
+   "de lignes\\n",
 
    ".Fr8.chooseCPattern:"
    "Inspectez la feuille d'alignement et determinez l'échantillon\\n"
@@ -2464,6 +2482,12 @@ char *fallbackResources[] = {
    "dell'ultima stampa effettuata.\\n"
    "Inserisci di nuovo il foglio nella stampante.",
 
+   ".It.sampleNo:"
+   "campione #",
+
+   ".It.choosePattern2:"
+   "Analizza le linee stampate e scegli la miglior coppia\\n",
+
    ".It.chooseCPattern:"
    "Analizza l'allineamento del foglio, e trova quale\\n"
    "schema sia il pi fine.\\n"
@@ -2698,6 +2722,12 @@ char *fallbackResources[] = {
    "dell'ultima stampa effettuata.\\n"
    "Inserisci di nuovo il foglio nella stampante.",
 
+   ".It8.sampleNo:"
+   "campione #",
+
+   ".It8.choosePattern2:"
+   "Analizza le linee stampate e scegli la miglior coppia\\n",
+
    ".It8.chooseCPattern:"
    "Analizza l'allineamento del foglio, e trova quale\\n"
    "schema sia il più fine.\\n"
