@@ -43,7 +43,7 @@
 #include "version.h"
 
 #include "d4lib.h"
-#include "d4libh.h"
+//#include "d4libh.h"
 
 #include "rdPrtDesc.h"
 #define defaultConfigData configData
@@ -602,7 +602,7 @@ int main(int argc, char **argv)
             fprintText(stdout, "%s\n", lang,"followingPrintersFound");
             for ( i = 0; i < state; i++)
             {
-               printf("%2d: %s\n",i+1, devices[i].prtname);     
+               printf("%2d: %s\n",i+1, devices[i].prtname);
             }
             fprintText(stdout, "%s\n", lang,"ChoosePrinter");
             state = askNo(1,state);
@@ -624,7 +624,7 @@ int main(int argc, char **argv)
             state--;
             snprintf(prtFile, sizeof(prtFile),USB_PRT_NAME_PREFIX"%02d:%s",state,s);
             model  = strdup(s);
-            printerName = strdup(s);            
+            printerName = strdup(s);
             device = prtFile;
             printerFound = 1;
          }
@@ -1304,8 +1304,9 @@ int alignHeads(char *lang, configData_t actConfig)
       for ( pass = 0; pass < passes; pass++ )
       {
          /* ask for pattern # */
-         printText("\n%s", lang, "choosePattern2");
-         printf("%d.\n ",pass+1);
+         printText("\n\n%s", lang, "sampleNo");
+         printf("%d\n",pass+1);
+         printText("%s", lang, "choosePattern2");
          patternNo |= askNo(1,choices) << (8*pass);
          /* save the pattern number */
       }
