@@ -31,15 +31,15 @@
 #include <stdio.h>
 #include <errno.h>
 #include <strings.h>
+#include <string.h>
 #include <usb.h>
 #include "usbHlp.h"
 #include "d4lib.h"
-#include "d4libh.h"
 #include "mtink.h"
 #include "cmd.h"
 
 
-/*#define DEBUG 1 */
+/*#define DEBUG 1*/
 
 /* Storage for our informations */
 #define MAX_DEVICES 100
